package org.geotools.referencing.factory.epsg;

import java.sql.Connection;

import org.geotools.factory.Hints;
import org.geotools.metadata.iso.citation.Citations;
import org.geotools.resources.i18n.ErrorKeys;
import org.geotools.resources.i18n.Errors;
import org.opengis.metadata.citation.Citation;
import org.opengis.referencing.FactoryException;
import org.opengis.referencing.NoSuchAuthorityCodeException;
import org.opengis.referencing.crs.CoordinateReferenceSystem;

/**
 * IGNFPATCH
 * The HTTPAnsiDialegtIgnFactory extends AnsiDialectIgnFactory
 * for the HTTP SRS definition in the IGNF namespace.
 *
 */
public class HTTPAnsiDialectIgnfFactory extends AnsiDialectIgnfFactory {

	public static final String BASE_URL = "http://librairies.ign.fr/geoportail/resources/RIG.xml#";
	
	/**
	 * Constructor
	 * @param userHints
	 * @param connection
	 */
	public HTTPAnsiDialectIgnfFactory(Hints userHints, Connection connection) {
        super(userHints, connection);
        setSchema("ignf_");
	}


	/**
	 * Returns the authority of the namespace
	 * => IGNF
	 */
    public synchronized Citation getAuthority() {
        return Citations.IGNF; 
    }

    /**
     * Redefinition and extensions of the FactoryAdapter for the IGN HTTP URI.
     */
	public synchronized CoordinateReferenceSystem createCoordinateReferenceSystem(
			String code) throws FactoryException {
		
		if (code.toLowerCase().contains("http"))
		{
			code = this.toBackingFactoryCode(code);
		}	
		return super.createCoordinateReferenceSystem(code);
}
	
    /**
     * Removes the URL base ({@value #BASE_URL}) from the specified code
     * before to pass it to the wrapped factories.
     *
     * @param  code The code given to this factory.
     * @return The code to give to the underlying factories.
     * @throws FactoryException if the code can't be converted.
     */
    protected String toBackingFactoryCode(String code) throws FactoryException {
        code = code.trim();
        
        final int length = BASE_URL.length();
        if (code.regionMatches(true, 0, BASE_URL, 0, length)) {
            code = code.substring(length);
                    return code;
                }
        
        
        

        throw new NoSuchAuthorityCodeException(Errors.format(ErrorKeys.ILLEGAL_ARGUMENT_$2,
                "code", code), BASE_URL, code);
    }
    
    
	
    
	

}
