	/*
 *    GeoTools - OpenSource mapping toolkit
 *    http://geotools.org
 *    (C) 2004-2006, GeoTools Project Managment Committee (PMC)
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    version 2.1 of the License.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package org.geotools.referencing.factory.epsg;

import java.util.Arrays;
import java.util.Set;
import java.util.Iterator;

import junit.framework.AssertionFailedError;
import junit.framework.TestCase;


import org.opengis.referencing.NoSuchAuthorityCodeException;
import org.opengis.referencing.crs.CoordinateReferenceSystem;
import org.opengis.referencing.operation.CoordinateOperation;
import org.opengis.referencing.operation.MathTransform;
import org.opengis.referencing.operation.TransformException;
import org.opengis.metadata.citation.Citation;
import org.opengis.geometry.DirectPosition;


import org.geotools.geometry.GeneralDirectPosition;
import org.geotools.referencing.CRS;
import org.geotools.referencing.ReferencingFactoryFinder;
import org.geotools.geometry.DirectPosition2D;
import org.geotools.metadata.iso.citation.Citations;



/**
 * @author Jody Garnett
 * @source $URL: http://svn.geotools.org/geotools/tags/2.4-RC0/modules/plugin/epsg-wkt/src/test/java/org/geotools/referencing/crs/CRSTest.java $
 */
public class IGNFCRSTest extends TestCase {

    ThreadedPostgreSQLIgnfFactory factory;


    protected void setUp() throws Exception {
        super.setUp();
        factory = new ThreadedPostgreSQLIgnfFactory();
    }

    public void testAuthority(){
        Citation authority = factory.getAuthority();        
        assertNotNull( authority );
        assertEquals( "National Mapping Agency (France)", authority.getTitle().toString() );
        assertTrue( authority.getIdentifiers().contains( "IGNF" ) );
    }
    
    public void testVendor(){
        Citation vendor = factory.getVendor();        
        assertNotNull( vendor );
        assertEquals( "Geotools", vendor.getTitle().toString() );
    }
    
    public void testCodes() throws Exception {
        Set codes = factory.getAuthorityCodes( CoordinateReferenceSystem.class );
        Iterator iter = codes.iterator();
        assertNotNull( codes );
    }
    
    public void testGppCodes() throws Exception {
      final String[] GppCodes = {"IGNF:LAMB93", "IGNF:GEOPORTALFXX", "IGNF:LAMBE", "IGNF:UTM20W84MART",
        "IGNF:GEOPORTALANF", "IGNF:MART38UTM20", "IGNF:UTM20W84GUAD", "IGNF:GUAD48UTM20", "IGNF:GEOPORTALMYT",
        "IGNF:RGM04UTM38S", "IGNF:MAYO50UTM38S", "IGNF:RGR92UTM40S", "IGNF:GEOPORTALREU", "IGNF:REUN47GAUSSL",
        "IGNF:GEOPORTALGUF", "IGNF:UTM22RGFG95", "IGNF:CSG67UTM22", "IGNF:UTM01SW84", "IGNF:GEOPORTALWLF",
        "IGNF:WALL78UTM1S", "IGNF:RGPFUTM5S", "IGNF:GEOPORTALPYF", "IGNF:TAHAAUTM05S", "IGNF:RGPFUTM6S",
        "IGNF:MOOREA87U6S", "IGNF:TAHI79UTM6S", "IGNF:RGPFUTM7S", "IGNF:NUKU72U7S", "IGNF:IGN63UTM7S", 
        "IGNF:RGSPM06U21", "IGNF:GEOPORTALSPM", "IGNF:STPM50UTM21", "IGNF:GUADFM49U20", "IGNF:RGNCUTM57S",
        "IGNF:GEOPORTALNCL", "IGNF:RGNCUTM58S", "IGNF:IGN72UTM58S", "IGNF:RGNCUTM59S", "IGNF:UTM39SW84",
        "IGNF:GEOPORTALCRZ", "IGNF:CROZ63UTM39S", "IGNF:UTM43SW84", "IGNF:AMST63UTM43S", "IGNF:UTM42SW84",
        "IGNF:GEOPORTALKER", "IGNF:KERG62UTM42S", "IGNF:TERA50STEREO", "IGNF:MILLER", "IGNF:RGF93G", 
        "IGNF:NTFP", "IGNF:WGS84RRAFGEO", "IGNF:MART38GEO", "IGNF:GUAD48GEO", "IGNF:RGM04GEO", "IGNF:MAYO50GEO", 
        "IGNF:RGR92GEO", "IGNF:REUN47GEO", "IGNF:RGFG95GEO", "IGNF:CSG67GEO", "IGNF:WGS84G", "IGNF:WALL78GEO",
        "IGNF:RGPFGEO", "IGNF:TAHAAGEO", "IGNF:MOOREA87GEO", "IGNF:TAHI79GEO", "IGNF:NUKU72GEO", 
        "IGNF:IGN63GEO", "IGNF:RGSPM06GEO", "IGNF:STPM50GEO", "IGNF:GUADFM49GEO", "IGNF:RGNCGEO",
        "IGNF:IGN72GEO", "IGNF:CROZ63GEO", "IGNF:AMST63GEO", "IGNF:KERG62GEO", "IGNF:TERA50GEO"};
      
      for(int i = 0; i < GppCodes.length; i++) {
        CoordinateReferenceSystem crs = (CoordinateReferenceSystem) factory.createObject(GppCodes[i]);
        assertNotNull( crs );
      }
    }
}
